ArrowManeuverStyle class final

The style that is used to display arrow maneuvers on the map.

Available extensions

Constructors

ArrowManeuverStyle(Color fillColor, Color outlineColor, {required double outlineWidth, required double length, required double triangleHeight, required bool enabled})
const

Properties

enabled → bool
Enables/disables arrow maneuvers.
final
fillColor → Color
Fill color of the arrow.
final
hashCode → int
The hash code for this object.
no setteroverride
length → double
Overall length of the arrow (including the tip) in units.
final
outlineColor → Color
Color of the arrow's outline.
final
outlineWidth → double
Width of the arrow's outline in units.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triangleHeight → double
Height of the arrow tip in units.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ArrowManeuverStyle other) → bool
The equality operator.
override