DrivingAvoidanceFlags class final

Constructors

DrivingAvoidanceFlags({bool avoidTolls = false, bool avoidUnpaved = false, bool avoidPoorCondition = false, bool avoidRailwayCrossing = false, bool avoidBoatFerry = false, bool avoidFordCrossing = false, bool avoidTunnel = false, bool avoidHighway = false})
const

Properties

avoidBoatFerry → bool
The 'avoidBoatFerry' option instructs the router to return routes that avoid ferries when possible.
final
avoidFordCrossing → bool
The 'avoidFordCrossing' option instructs the router to return routes that avoid ford crossings when possible.
final
avoidHighway → bool
The 'avoidHighway' option instructs the router to return routes that avoid highways when possible.
final
avoidPoorCondition → bool
The 'avoidPoorCondition' option instructs the router to return routes that avoid roads in poor conditions when possible.
final
avoidRailwayCrossing → bool
The 'avoidPoorConditions' option instructs the router to return routes that avoid railway crossings when possible.
final
avoidTolls → bool
The 'avoidTolls' option instructs the router to return routes that avoid tolls when possible.
final
avoidTunnel → bool
The 'avoidTunnel' option instructs the router to return routes that avoid tunnels when possible.
final
avoidUnpaved → bool
The 'avoidUnpaved' option instructs the router to return routes that avoid unpaved roads when possible.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingAvoidanceFlags other) → bool
The equality operator.
override