DrivingCheckpoint class final

A checkpoint object.

Available extensions

Constructors

DrivingCheckpoint(PolylinePosition position)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → PolylinePosition
The position of the checkpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingCheckpoint other) → bool
The equality operator.
override