DrivingDirectionSignExit class final

Available extensions

Constructors

DrivingDirectionSignExit(DrivingDirectionSignStyle style, {required String name})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → DrivingDirectionSignStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingDirectionSignExit other) → bool
The equality operator.
override