DrivingDirectionSignItem class final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asDirectionSignExit() → DrivingDirectionSignExit?
asDirectionSignIcon() → DrivingDirectionSignIcon?
asDirectionSignRoad() → DrivingDirectionSignRoad?
asDirectionSignToponym() → DrivingDirectionSignToponym?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onDirectionSignToponym(DrivingDirectionSignToponym value), required void onDirectionSignRoad(DrivingDirectionSignRoad value), required void onDirectionSignExit(DrivingDirectionSignExit value), required void onDirectionSignIcon(DrivingDirectionSignIcon value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited