DrivingDirectionSignStyle class final

Available extensions

Constructors

DrivingDirectionSignStyle(Color textColor, Color bgColor)
const

Properties

bgColor → Color
Background color in RGB format
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColor → Color
Text color in RGB format
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingDirectionSignStyle other) → bool
The equality operator.
override