DrivingEvent class abstract final

Road event.

Implemented types

Constructors

DrivingEvent(PolylinePosition polylinePosition, String eventId, String? descriptionText, List<RoadEventsEventTag> tags, Point location, double? speedLimit)
factory

Properties

descriptionText → String?
The description of the event.
no setter
eventId → String
The unique ID of the event.
no setter
hashCode → int
The hash code for this object.
no setteroverride
location → Point
The location of the road event.
no setter
polylinePosition → PolylinePosition
The position of the polyline.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speedLimit → double?
The speed limit on the road. Valid only for cameras.
no setter
tags → List<RoadEventsEventTag>
The types of the road event.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingEvent other) → bool
The equality operator.
override