DrivingLane class abstract final

The lane object.

Implemented types

Constructors

DrivingLane(DrivingLaneKind laneKind, List<DrivingLaneDirection> directions, DrivingLaneDirection? highlightedDirection)
factory

Properties

directions → List<DrivingLaneDirection>
Lane direction.
no setter
hashCode → int
The hash code for this object.
no setteroverride
highlightedDirection → DrivingLaneDirection?
Highlighted lane direction.
no setter
laneKind → DrivingLaneKind
The type of lane.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingLane other) → bool
The equality operator.
override