DrivingManoeuvreVehicleRestriction class final

Available extensions

Constructors

DrivingManoeuvreVehicleRestriction(DrivingVehicleRestriction vehicleRestriction, PolylinePosition position)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → PolylinePosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vehicleRestriction → DrivingVehicleRestriction
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingManoeuvreVehicleRestriction other) → bool
The equality operator.
override