DrivingNonAvoidedFeatures class final

Available extensions

Constructors

DrivingNonAvoidedFeatures({required bool tolls, required bool ferries, required bool fordCrossings, required bool highways, required bool railwayCrossings, required bool tunnels, required bool inPoorConditionRoads, required bool unpavedRoads, required bool avoidZones})
const

Properties

avoidZones → bool
final
ferries → bool
final
fordCrossings → bool
final
hashCode → int
The hash code for this object.
no setteroverride
highways → bool
final
inPoorConditionRoads → bool
final
railwayCrossings → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tolls → bool
final
tunnels → bool
final
unpavedRoads → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingNonAvoidedFeatures other) → bool
The equality operator.
override