DrivingOptions class final

Driving options.

Constructors

DrivingOptions({double? initialAzimuth, int? routesCount, DateTime? departureTime, AnnotationLanguage? annotationLanguage, DrivingAvoidanceFlags? avoidanceFlags})
const

Properties

annotationLanguage → AnnotationLanguage?
A method to set the annotation language. lang The annotation language.
final
avoidanceFlags → DrivingAvoidanceFlags?
The 'avoidanceFlags' instruct the router to return routes that avoid roads with the specified properties when possible.
final
departureTime → DateTime?
final
hashCode → int
The hash code for this object.
no setteroverride
initialAzimuth → double?
Starting location azimuth.
final
routesCount → int?
The number of alternatives.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingOptions other) → bool
The equality operator.
override