DrivingRailwayCrossing class final

A railway crossing object.

Available extensions

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → PolylinePosition
The position of railway crossing.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DrivingRailwayCrossingType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingRailwayCrossing other) → bool
The equality operator.
override