DrivingRestrictedEntry class final

A restricted entry object.

Available extensions

Constructors

DrivingRestrictedEntry(PolylinePosition position)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → PolylinePosition
The position of the restricted entry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingRestrictedEntry other) → bool
The equality operator.
override