DrivingRoutePoint class abstract final

Route point metadata (exists for both waypoints and via points).

Implemented types

Constructors

DrivingRoutePoint(Point position, Point? selectedArrivalPoint)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → Point
Position of original route point.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedArrivalPoint → Point?
Arrival point selected for routing.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingRoutePoint other) → bool
The equality operator.
override