DrivingRouter class abstract

Interface for the driving router.

Implemented types

Constructors

DrivingRouter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

matchRoute(Polyline polyline, DrivingOptions drivingOptions, DrivingVehicleOptions vehicleOptions, DrivingSessionRouteListener routeListener) → DrivingSession
Builds a route based on a custom route geometry.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestRoutes(DrivingOptions drivingOptions, DrivingVehicleOptions vehicleOptions, DrivingSessionRouteListener routeListener, {required List<RequestPoint> points}) → DrivingSession
Builds a route.
requestRoutesSummary(DrivingOptions drivingOptions, DrivingVehicleOptions vehicleOptions, DrivingSummarySessionSummaryListener summaryListener, {required List<RequestPoint> points}) → DrivingSummarySession
Creates a route summary.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited