DrivingSection class abstract final

Route section.

Implemented types

Constructors

DrivingSection(DrivingSectionMetadata metadata, Subpolyline geometry)
factory

Properties

geometry → Subpolyline
A polyline of the route section.
no setter
hashCode → int
The hash code for this object.
no setteroverride
metadata → DrivingSectionMetadata
Metadata information for the route section.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingSection other) → bool
The equality operator.
override