DrivingSummary class final

Route summary.

Available extensions

Constructors

DrivingSummary(DrivingWeight weight, DrivingFlags flags, DrivingNonAvoidedFeatures nonAvoidedFeatures)
const

Properties

flags → DrivingFlags
Overall route characteristics.
final
hashCode → int
The hash code for this object.
no setteroverride
nonAvoidedFeatures → DrivingNonAvoidedFeatures
Route features that cannot be avoided
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → DrivingWeight
Route "weight".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingSummary other) → bool
The equality operator.
override