DrivingTollPost class final

A toll post object.

Available extensions

Constructors

DrivingTollPost(PolylinePosition position, {int? id, double? time_with_traffic, bool? nonTransactional})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → int?
final
nonTransactional → bool?
final
position → PolylinePosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time_with_traffic → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingTollPost other) → bool
The equality operator.
override