DrivingToponymPhrase class abstract final

The description of the object.

Implemented types

Constructors

DrivingToponymPhrase(String text, int? actionProximity)
factory

Properties

actionProximity → int?
Positions at which text should be pronounced.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The string containing the description.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingToponymPhrase other) → bool
The equality operator.
override