DrivingVehicleOptions class final

Constructors

DrivingVehicleOptions({DrivingVehicleType vehicleType = directions_driving_vehicle_type.DrivingVehicleType.Default, double? weight, double? axleWeight, double? maxWeight, double? height, double? width, double? length, double? payload, int? ecoClass, bool? hasTrailer, bool? buswayPermitted})
const

Properties

axleWeight → double?
Maximal weight supported by a vehicle axle.
final
buswayPermitted → bool?
The vehicle is permitted for busway.
final
ecoClass → int?
Vehicle eco class.
final
hashCode → int
The hash code for this object.
no setteroverride
hasTrailer → bool?
The vehicle has a trailer attached.
final
height → double?
Vehicle height.
final
length → double?
Vehicle length.
final
maxWeight → double?
Maximal allowed weight for the vehicle.
final
payload → double?
Vehicle cargo weight.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vehicleType → DrivingVehicleType
Sets the vehicle type for special routing.
final
weight → double?
Real vehicle weight.
final
width → double?
Vehicle width.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingVehicleOptions other) → bool
The equality operator.
override