DrivingVehicleOptionsNative class final

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
axleWeight ↔ Pointer<Void>
getter/setter pair
buswayPermitted ↔ Pointer<Void>
getter/setter pair
ecoClass ↔ Pointer<Void>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasTrailer ↔ Pointer<Void>
getter/setter pair
height ↔ Pointer<Void>
getter/setter pair
length ↔ Pointer<Void>
getter/setter pair
maxWeight ↔ Pointer<Void>
getter/setter pair
payload ↔ Pointer<Void>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vehicleType ↔ int
getter/setter pair
weight ↔ Pointer<Void>
getter/setter pair
width ↔ Pointer<Void>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited