DrivingVehicleRestriction class final

Available extensions

Constructors

DrivingVehicleRestriction({double? weightLimit, double? axleWeightLimit, double? maxWeightLimit, double? heightLimit, double? widthLimit, double? lengthLimit, double? payloadLimit, int? minEcoClass, bool? trailerNotAllowed, bool? legal})
const

Properties

axleWeightLimit → double?
Axle load weight limit, tons. See Driving Rules sign 3.12.
final
hashCode → int
The hash code for this object.
no setteroverride
heightLimit → double?
Height limit, meters. See Driving Rules sign 3.13.
final
Legal or physical limitation.
final
lengthLimit → double?
Length limit, meters. See Driving Rules sign 3.15.
final
maxWeightLimit → double?
Maximal allowed weight limit, tons. See Driving Rules sign 3.4, table 8.11.
final
minEcoClass → int?
Minimal allowed engine ecological class. See Driving Rules sign 5.35 and 5.36.
final
payloadLimit → double?
Payload limit, tons.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trailerNotAllowed → bool?
Trailer is not allowed. See Driving Rules sign 3.7.
final
weightLimit → double?
Actual weight limit, tons. See Driving Rules sign 3.11.
final
widthLimit → double?
Width limit, meters. See Driving Rules sign 3.14.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingVehicleRestriction other) → bool
The equality operator.
override