LocalizedPhrase class abstract final

Implemented types

Constructors

LocalizedPhrase(List<SpeakerPhraseToken> tokens, String text, AnnotationLanguage language)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
language → AnnotationLanguage
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
no setter
tokens → List<SpeakerPhraseToken>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LocalizedPhrase other) → bool
The equality operator.
override