RoadEvent class abstract final

Implemented types

Constructors

RoadEvent(String id, Point position, List<RoadEventsEventTag> tags, String caption, bool isInFuture)
factory

Properties

caption → String
Text caption displayed under the road event icon.
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → String
The road event unique id.
no setter
isInFuture → bool
Some road events can be not active yet, but still must be displayed to notify users about future events, for example drawbridges or closures. Usually such events have a greyscale icon and/or clock drawn in the icon's corner.
no setter
position → Point
Position of the road event on the globe.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<RoadEventsEventTag>
Set of road event tags.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant RoadEvent other) → bool
The equality operator.
override