RoadEventsLayerStyleProvider class abstract

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
provideStyle(RoadEventsLayerRoadEventStylingProperties roadEventStylingProperties, bool isNightMode, double scaleFactor, RoadEventsLayerRoadEventStyle style) → bool
Provide style for given road event. Must produce same style for same input arguments.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited