RoadEventsLayerTextStyle class abstract final

Implemented types

Constructors

RoadEventsLayerTextStyle(double fontSize, Color color, Color? outlineColor)
factory

Properties

color → Color
Text primary color.
no setter
fontSize → double
Font size in device-independent pixels.
no setter
hashCode → int
The hash code for this object.
no setteroverride
outlineColor → Color?
Text outline color.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant RoadEventsLayerTextStyle other) → bool
The equality operator.
override