AirshipTapInfo class abstract final

Inheritance
Implemented types

Constructors

AirshipTapInfo(String panoramaId)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
panoramaId → String
Panorama id of the tapped airship. The id may be used to open panorama in the panorama player
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant AirshipTapInfo other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<AirshipTapInfo>
final