HistoricalPanorama class final

Available extensions

Constructors

HistoricalPanorama(DateTime timestamp, {required String name, required String panoramaId})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
final
panoramaId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant HistoricalPanorama other) → bool
The equality operator.
override