PanoramaArrowConnection class abstract final

Implemented types

Constructors

PanoramaArrowConnection(Direction angularPosition, String label, PanoramaArrowConnectionStyle arrowStyle, String panoramaId)
factory

Properties

angularPosition → Direction
Angular position, degrees. (bearing, tilt) (0, 0) - (north, horizon)
no setter
arrowStyle → PanoramaArrowConnectionStyle
Arrow style.
no setter
hashCode → int
The hash code for this object.
no setteroverride
label → String
label is shown near the arrow
no setter
panoramaId → String
panoramaId is passed as a parameter to the onPanoramaChangeIntent method.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant PanoramaArrowConnection other) → bool
The equality operator.
override