PanoramaDescription class abstract final

Implemented types

Constructors

PanoramaDescription(String panoramaId, PanoramaPosition? position, PanoramaAngularBoundingBox angularBBox, PanoramaImageSize tileSize, List<PanoramaTileLevel> tileLevels, List<PanoramaIconMarker> iconMarkers, List<PanoramaTextMarker> textMarkers, List<PanoramaCompanyMarker> companyMarkers, List<PanoramaIconConnection> iconConnections, List<PanoramaArrowConnection> arrowConnections, Direction direction, Span span, Attribution? attribution)
factory

Properties

angularBBox → PanoramaAngularBoundingBox
The angularBBox field sets how the tile tilelevels oriented in space. Direction + span will be limited between top and bottom The recommendation for initializing angular bbox: (right - left) == 360. Non 360 degrees panoramas are not supported yet. (top - bottom) <= 180 The angular aspect ratio must be the same as any tileLevel aspect ratio. (right - left)/(top - bottom) == tileLevel[i].width/tileLevel[i].height
no setter
arrowConnections → List<PanoramaArrowConnection>
Add standard player arrow connections
no setter
attribution → Attribution?
Panorama author information.
no setter
companyMarkers → List<PanoramaCompanyMarker>
Add company icons and labels to the panorama
no setter
direction → Direction
Suggest where to look at once panorama is opened. It's just a recommendation because it depends on angularBBox and span.
no setter
hashCode → int
The hash code for this object.
no setteroverride
iconConnections → List<PanoramaIconConnection>
Add icons with interaction
no setter
iconMarkers → List<PanoramaIconMarker>
Add marker icons to the panorama
no setter
panoramaId → String
panoramaId is passed as a parameter to the TileImageFactory or to the TileUrlProvider
no setter
position → PanoramaPosition?
Geo position.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → Span
Suggest view area span. It's just a recommendation because it depends on angularBBox and direction.
no setter
textMarkers → List<PanoramaTextMarker>
Add marker text to the panorama
no setter
tileLevels → List<PanoramaTileLevel>
The tileLevels is a set of the TileLevel structs. Tile levels can be added in any order. It's recommended to have at least 2 tile levels:
no setter
tileSize → PanoramaImageSize
Any tile level imageSize width must be multiple of the tileSize width. Only 256x256 and 512x512 tiles are supported.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant PanoramaDescription other) → bool
The equality operator.
override