PanoramaPlayer class abstract

Panorama player that is used to open panoramas.

Implemented types

Constructors

PanoramaPlayer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
Yandex logo object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCompanyTapListener(PanoramaCompanyTapListener companyTapListener) → void
Adds company tap listener.
addDirectionChangeListener(PanoramaDirectionChangeListener directionChangeListener) → void
Adds direction listener.
addErrorListener(PanoramaErrorListener errorListener) → void
Adds error listener.
addPanoramaChangeListener(PanoramaChangeListener panoramaChangeListener) → void
Adds a panorama change listener.
addSpanChangeListener(PanoramaSpanChangeListener spanChangeListener) → void
Adds span listener.
companiesEnabled() → bool
Checks if companies are enabled.
direction() → Direction
View direction of the opened panorama. Return View direction of the opened panorama. Empty if no panorama is open.
disableCompanies() → void
Disallows companies (company names and icons) to be shown.
disableLoadingWheel() → void
Disallows showing loading wheels.
disableMarkers() → void
Disallows markers (house numbers, railway stations, airports) to be shown.
disableMove() → void
Hides transition arrows and disallows switching panoramas.
disableRotation() → void
Disallows the user to rotate panoramas.
disableZoom() → void
Disables player zoom controls.
enableCompanies() → void
Allows companies (company names and icons) to be shown.
enableLoadingWheel() → void
Allows showing loading wheels.
enableMarkers() → void
Allows markers (house numbers, railway stations, airports) to be shown.
enableMove() → void
Shows transition arrows and allows switching panoramas.
enableRotation() → void
Allows the user to rotate panoramas.
enableZoom() → void
Enables player zoom controls.
historicalPanoramas() → List<HistoricalPanorama>
Return panoramas published earlier at the current panorama position. Result is updated on the PanoramaChangeListener callback
isValid() → bool
loadingWheelEnabled() → bool
Checks if loading wheels can be shown while the panorama is opening.
lookAt(Point position) → void
Sets the view direction to the center of the given geo position.
markersEnabled() → bool
Checks if markers are enabled.
moveEnabled() → bool
Checks if switching panoramas is enabled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMemoryWarning() → void
Called when a memory warning happens.
openPanorama(String panoramaId) → void
Opens the panorama with the given ID.
openUserPanoramaWithLocalDataSource(PanoramaDescription panoramaDescription, PanoramaTileImageFactory tileImageProvider, PanoramaIconImageFactory iconImageProvider, PanoramaUserPanoramaEventListener userPanoramaEventListener) → void
Opens the panorama from the local datasource.
openUserPanoramaWithNetworkDataSource(PanoramaDescription panoramaDescription, PanoramaTileUrlProvider tileUrlProvider, PanoramaIconUrlProvider iconUrlProvider, PanoramaUserPanoramaEventListener userPanoramaEventListener) → void
Opens the panorama from the network datasource.
panoramaId() → String
Opened the panorama with the given ID. Return PanoramaId of the currently opened panorama. Empty if no panorama is open.
position() → Point
Geo position of current panorama. Return Geo position of the currently opened panorama. Empty if no panorama is open.
removeCompanyTapListener(PanoramaCompanyTapListener companyTapListener) → void
Removes company tap listener.
removeDirectionChangeListener(PanoramaDirectionChangeListener directionChangeListener) → void
Removes the direction listener.
removeErrorListener(PanoramaErrorListener errorListener) → void
Removes error listener.
removePanoramaChangeListener(PanoramaChangeListener panoramaChangeListener) → void
Removes the panorama change listener.
removeSpanChangeListener(PanoramaSpanChangeListener spanChangeListener) → void
Removes span listener.
reset() → void
Closes the opened panorama and stops all player actions.
rotationEnabled() → bool
Checks if player rotation is enabled.
setDirection(Direction direction) → void
Sets the view direction bearing and tilt.
setSpan(Span span) → void
Sets the view area span. Invalid values are adjusted by the player to the closest valid values.
span() → Span
View span of the opened panorama. Return Current view span of the opened panorama. May be different from the span provided by the setSpan(span) method.
toString() → String
A string representation of this object.
inherited
zoomEnabled() → bool
Checks if zoom controls are enabled.

Operators

operator ==(Object other) → bool
The equality operator.
inherited