PanoramaTileLevel class abstract final

The TileLevel struct.

Implemented types

Constructors

PanoramaTileLevel(int level, PanoramaImageSize imageSize)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
imageSize → PanoramaImageSize
Source image size. The imageSize width must be multiples of the tileSize width. The imageSize height must be in range [1..imageSize.width/2]
no setter
level → int
level is passed as a parameter to the TileImageFactory or to the TileUrlProvider. Each panorama description tile level must have unique value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant PanoramaTileLevel other) → bool
The equality operator.
override