Places class abstract

Implemented types
Implementers

Constructors

Places()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPanoramaLayer(MapWindow mapWindow) → PanoramaLayer
Creates a layer representing where panoramas are available.
createPanoramaService() → PanoramaService
Creates a service that allows to find a panorama closest to the chosen point.
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited