SearchAddressComponentKind enum

An address component kind, for example, large administrative area.

Inheritance
Available extensions

Values

Unknown → const SearchAddressComponentKind

Unknown component kind

Country → const SearchAddressComponentKind

Country component.

Region → const SearchAddressComponentKind

Region component.

Province → const SearchAddressComponentKind

Province component.

Area → const SearchAddressComponentKind

Area component.

Locality → const SearchAddressComponentKind

Locality component.

District → const SearchAddressComponentKind

District component.

Street → const SearchAddressComponentKind

Street component.

House → const SearchAddressComponentKind

House component.

Entrance → const SearchAddressComponentKind

Entrance component.

Level → const SearchAddressComponentKind

Indoor level component.

Apartment → const SearchAddressComponentKind

Apartment component.

Route → const SearchAddressComponentKind

Line component.

Station → const SearchAddressComponentKind

Generic station component.

MetroStation → const SearchAddressComponentKind

Metro station component.

RailwayStation → const SearchAddressComponentKind

Railway station component.

Vegetation → const SearchAddressComponentKind

Vegetation component.

Hydro → const SearchAddressComponentKind

Hydro component.

Airport → const SearchAddressComponentKind

Airport component.

Other → const SearchAddressComponentKind

Kind for other toponyms, for example cemeteries or some other landmarks, which can't be easily described by kinds.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SearchAddressComponentKind>
A constant List of the values in this enum, in order of their declaration.