SearchBusinessFilterBooleanValue class final

Value for boolean filters.

Available extensions

Constructors

SearchBusinessFilterBooleanValue({required bool value, bool? selected})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool?
Selected marker. Set in server response for selected filters.
final
value → bool
Filter value. Set in server reponse for selected filters.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchBusinessFilterBooleanValue other) → bool
The equality operator.
override