SearchBusinessFilterGroup class abstract final

Group of filters.

Implemented types

Constructors

SearchBusinessFilterGroup(String? name, List<String> filterIds)
factory

Properties

filterIds List<String>
IDs for filters in the group.
no setter
hashCode int
The hash code for this object.
no setteroverride
name String?
Group name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant SearchBusinessFilterGroup other) bool
The equality operator.
override