SearchBusinessFilterValues class final

Possible filter values.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asDateValue() → SearchBusinessFilterDateValue?
asRangeValue() → SearchBusinessFilterRangeValue?
asVectorBooleanValue() → List<SearchBusinessFilterBooleanValue>?
asVectorEnumValue() → List<SearchBusinessFilterEnumValue>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onVectorBooleanValue(List<SearchBusinessFilterBooleanValue> value), required void onVectorEnumValue(List<SearchBusinessFilterEnumValue> value), required void onRangeValue(SearchBusinessFilterRangeValue value), required void onDateValue(SearchBusinessFilterDateValue value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited