SearchBusinessObjectMetadata class abstract final

Extended information about company.

Inheritance
Implemented types

Constructors

SearchBusinessObjectMetadata(String oid, String name, SearchAddress address, List<SearchCategory> categories, List<SearchPhone> phones, SearchWorkingHours? workingHours, SearchPrecision? precision, List<SearchFeature> features, SearchFeatureSet? importantFeatures, List<SearchLink> links, LocalizedValue? distance, List<SearchChain> chains, SearchClosed? closed, bool? unreliable, String? seoname, String? shortName, SearchProperties? properties, List<SearchFeatureGroup> featureGroups, String? indoorLevel)
factory

Properties

address → SearchAddress
Company address.
no setter
categories → List<SearchCategory>
List of categories associated with the company.
no setter
chains → List<SearchChain>
List of chains associated with the company.
no setter
closed → SearchClosed?
Company status, present if it is closed.
no setter
distance → LocalizedValue?
Optional distance to the company from geometry provided in request.
no setter
featureGroups → List<SearchFeatureGroup>
List of feature groups for the company.
no setter
features → List<SearchFeature>
List of features for the company.
no setter
hashCode → int
The hash code for this object.
no setteroverride
importantFeatures → SearchFeatureSet?
Collection of features that probably are of utmost interest to the user.
no setter
indoorLevel → String?
Indoor level id (obsolete).
no setter
List of links for the company.
no setter
name → String
Company name.
no setter
oid → String
Permanent company id.
no setter
phones → List<SearchPhone>
List of phone numbers for the company.
no setter
precision → SearchPrecision?
Address precision for the company.
no setter
properties → SearchProperties?
Additional company properties.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seoname → String?
Technical field for SEO (transliterated and simplified company name).
no setter
shortName → String?
Short company name.
no setter
unreliable → bool?
If true, company information is not reliable.
no setter
workingHours → SearchWorkingHours?
Open hours for the company.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchBusinessObjectMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchBusinessObjectMetadata>
final