SearchBusinessPhotoObjectMetadata class abstract final

Snippet for company-related photos (becoming obsolete).

Inheritance
Implemented types

Properties

count → int
Number of photos for the organisation. (see PhotosManager for details)
no setter
hashCode → int
The hash code for this object.
no setteroverride
photos → List<SearchBusinessPhotoObjectMetadataPhoto>
List of photos for the company (usually first three)
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchBusinessPhotoObjectMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchBusinessPhotoObjectMetadata>
final