SearchBusinessRating1xObjectMetadata class abstract final

Snippet for company ratings. Score from 0 to 5.

Inheritance
Implemented types

Constructors

SearchBusinessRating1xObjectMetadata(int ratings, int reviews, double? score)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
ratings → int
Total number of ratings.
no setter
reviews → int
Total number of reviews.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
Average rating score for the company (0 to 5).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchBusinessRating1xObjectMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchBusinessRating1xObjectMetadata>
final