SearchBusinessResultMetadata class abstract final

Common info for business search response.

Implemented types

Constructors

SearchBusinessResultMetadata(List<SearchCategory> categories, List<SearchChain> chains, List<SearchBusinessFilter> businessFilters, SearchFilterSet? importantFilters, List<SearchBusinessFilterGroup> filterGroups, List<String> pricesCurrencies)
factory

Properties

businessFilters → List<SearchBusinessFilter>
List of applicable filters.
no setter
categories → List<SearchCategory>
List of categories (also known as rubrics) present in response. Non-empty list means that the request was treated as a 'category request' by the server (for example requests like "where to eat", "cinema", and other).
no setter
chains → List<SearchChain>
List of chains present in response. Non-empty list means that the request was treaded as 'chain request' (for example "mcdonalds", "starbucks", and other).
no setter
filterGroups → List<SearchBusinessFilterGroup>
Grouped BusinessFilter's by their meaning.
no setter
hashCode → int
The hash code for this object.
no setteroverride
importantFilters → SearchFilterSet?
Collection of filters that probably are of utmost interest to the user.
no setter
pricesCurrencies → List<String>
Relevant currency for the prices
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchBusinessResultMetadata other) → bool
The equality operator.
override