SearchCategory class abstract final

Single category (also known as rubric) description.

Implemented types

Constructors

SearchCategory(String name, String? categoryClass, List<String> tags)
factory

Properties

categoryClass → String?
Category class. Different categories can have the same class. For example, "Bar", "Cafe" and "Restaurant" categories inhabit "restaurants" category class.
no setter
hashCode → int
The hash code for this object.
no setteroverride
name → String
Category name.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
Additional non-structured data for the category.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchCategory other) → bool
The equality operator.
override