SearchChain class final

Single chain (group of companies) description.

Available extensions

Constructors

SearchChain({required String id, required String name})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
Chain identifier.
final
name → String
Chain name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchChain other) → bool
The equality operator.
override