SearchCurrencyExchangeType class abstract final

Single currency exchange prices.

Implemented types

Constructors

SearchCurrencyExchangeType(String? name, TaxiMoney? buy, TaxiMoney? sell)
factory

Properties

buy → TaxiMoney?
Buy rate.
no setter
hashCode → int
The hash code for this object.
no setteroverride
name → String?
ISO-4217 currency name, for example "USD" or "RUB" or "EUR".
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sell → TaxiMoney?
Sell rate.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchCurrencyExchangeType other) → bool
The equality operator.
override