SearchDeleteAllPersonalSuggestSession class abstract

Interface to handle remove all user personalized suggest request. Allows request cancellation and retry.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels the current request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retry(PersonalSuggestListener personalSuggestListener) → void
Retries the last request. If there is an active request, it is cancelled.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited