SearchDisplayType enum

Result display type.

Inheritance
Available extensions

Values

Single → const SearchDisplayType

Each result makes sense without the others (that is toponyms), they probably shouldn'be displayed as a group, and probably there's no need to make additional requests after user moves the map or zooms in or out.

Multiple → const SearchDisplayType

Results are meaningful as a group (that is category query), they should be displayed all together, and it makes sense to send additional requests after user changes visible map region.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SearchDisplayType>
A constant List of the values in this enum, in order of their declaration.