SearchEntrance class abstract final

An entrance to a building

Implemented types

Constructors

SearchEntrance(String? name, Point point, Direction? direction)
factory

Properties

direction → Direction?
no setter
hashCode → int
The hash code for this object.
no setteroverride
name → String?
no setter
point → Point
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchEntrance other) → bool
The equality operator.
override