SearchFeature class abstract final

Describes some common feature of organizations. Can be of three types:

  • boolean (like on/off switch, as for free Wi-Fi availability).

  • enumerated (can have multiple values at once, like cuisine types in a cafe).

  • text (like enumerated but with any strings instead of predefined values).

Implemented types

Constructors

SearchFeature(String id, SearchFeatureVariantValue value, String? name, String? aref, Image? iconLight, Image? iconDark)
factory

Properties

aref → String?
Reference to information source providing given feature (see mapkit_attribution.Attribution)
no setter
hashCode → int
The hash code for this object.
no setteroverride
iconDark → Image?
no setter
iconLight → Image?
no setter
id → String
Machine readable feature identifier.
no setter
name → String?
Human readable localized representation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → SearchFeatureVariantValue
Feature value (depends on feature type).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchFeature other) → bool
The equality operator.
override