SearchFeatureGroup class abstract final

Group of features.

Implemented types

Constructors

SearchFeatureGroup(String? name, List<String> ids)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
ids → List<String>
IDs for features in the group.
no setter
name → String?
Group name.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchFeatureGroup other) → bool
The equality operator.
override