SearchFeatureVariantValue class final

A variant combining possible feature values.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asBooleanValue() → SearchFeatureBooleanValue?
asVectorEnumValue() → List<SearchFeatureEnumValue>?
asVectorString() → List<String>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onBooleanValue(SearchFeatureBooleanValue value), required void onVectorString(List<String> value), required void onVectorEnumValue(List<SearchFeatureEnumValue> value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited