SearchFilterCollectionNumberRange class final

Number range. Used for range filter.

Available extensions

Constructors

SearchFilterCollectionNumberRange({required double from, required double to})
const

Properties

from → double
Lower range limit.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → double
Upper range limit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchFilterCollectionNumberRange other) → bool
The equality operator.
override