SearchFuelType class abstract final

Fuel name and price.

Implemented types

Constructors

SearchFuelType(String? name, TaxiMoney? price)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String?
Fuel name.
no setter
price → TaxiMoney?
Fuel price.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchFuelType other) → bool
The equality operator.
override