SearchLink class final

Link structure. Combines actual link with attribution and type info.

Available extensions

Constructors

SearchLink(AttributionLink link, {String? aref, String? tag})
const

Properties

aref → String?
Attribution reference.
final
hashCode → int
The hash code for this object.
no setteroverride
Actual link.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
Link tag. Possible values (non-exhaustive) 'self/social/attribution/showtimes/booking'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchLink other) → bool
The equality operator.
override