SearchPanorama class final

Panorama info.

Available extensions

Constructors

SearchPanorama(Direction direction, Span span, Point point, {required String id})
const

Properties

direction → Direction
Direction of the panorama center.
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
Machine readable panorama identifier.
final
point → Point
Panorama point.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span → Span
H-Span and V-Span hints for the panorama player.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchPanorama other) → bool
The equality operator.
override