SearchParkingAttributes class abstract final

Implemented types

Constructors

SearchParkingAttributes(String? orgURI, TaxiMoney? firstHourPrice, int? placesCount)
factory

Properties

firstHourPrice → TaxiMoney?
Price of the first hour.
no setter
hashCode → int
The hash code for this object.
no setteroverride
orgURI → String?
Parking organization URI. For example, parking zone or any toll area or inside building parking.
no setter
placesCount → int?
Maximum number of parking places (capacity).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchParkingAttributes other) → bool
The equality operator.
override