SearchProperties class abstract final

Generic key-value property storage.

Implemented types

Constructors

SearchProperties(List<SearchPropertiesItem> items)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
items → List<SearchPropertiesItem>
Property list.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchProperties other) → bool
The equality operator.
override