SearchReferenceType class abstract final

The type of reference.

Implemented types

Constructors

SearchReferenceType(String id, String scope)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
Reference ID.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
Reference scope.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchReferenceType other) → bool
The equality operator.
override