SearchShowtime class abstract final

Session details.

Implemented types

Constructors

SearchShowtime(Time startTime, TaxiMoney? price, String? ticketId)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
price → TaxiMoney?
Ticket price.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → Time
Session start time.
no setter
ticketId → String?
Ticket id.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchShowtime other) → bool
The equality operator.
override