SearchSubtitleMetadata class abstract final

Subtitle snippet.

Inheritance
Implemented types

Constructors

SearchSubtitleMetadata(List<SearchSubtitleItem> subtitleItems, List<SearchSubtitleItem> serpSubtitleItems)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serpSubtitleItems → List<SearchSubtitleItem>
List of subtitles to be displayed in SERP.
no setter
subtitleItems → List<SearchSubtitleItem>
List of subtitles.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchSubtitleMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchSubtitleMetadata>
final