SearchSuggestSession class abstract

Implemented types

Constructors

SearchSuggestSession()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Cancels current suggest request and resets internal state. Next queries via this suggest session will be seen as a new suggest session from backend point of view.
suggest(BoundingBox window, SuggestOptions suggestOptions, SearchSuggestSessionSuggestListener suggestListener, {required String text}) → void
Begin a suggest request. The current request is cancelled, if present.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited