SearchToponymResultMetadata class abstract final

Common info for response from toponym search.

Inheritance
Implemented types

Constructors

SearchToponymResultMetadata(int found, SearchToponymResultMetadataResponseInfo? responseInfo, Point? reversePoint)
factory

Properties

found → int
Approximate number of found objects.
no setter
hashCode → int
The hash code for this object.
no setteroverride
responseInfo → SearchToponymResultMetadataResponseInfo?
Additional response info.
no setter
reversePoint → Point?
The search coordinates given via 'll' or parsed from 'text' (only in reverse mode).
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchToponymResultMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchToponymResultMetadata>
final