SearchToponymResultMetadataResponseInfo class final

Additional response info.

Available extensions

Properties

accuracy → double?
Search response accuracy.
final
hashCode → int
The hash code for this object.
no setteroverride
mode → SearchToponymResultMetadataSearchMode
Search mode.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchToponymResultMetadataResponseInfo other) → bool
The equality operator.
override