SearchType class final

Bitmask for requested search types.

Constructors

SearchType(int value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator &(SearchType other) → SearchType
operator ==(covariant SearchType other) → bool
The equality operator.
override
operator |(SearchType other) → SearchType
operator ~() → SearchType

Constants

Biz → const SearchType
Companies.
Geo → const SearchType
Toponyms.
None → const SearchType
Default value: all types requested.