SearchWorkingHours class abstract final

Open hours for an organization.

Implemented types

Constructors

SearchWorkingHours(String text, List<SearchAvailability> availabilities, SearchState? state)
factory

Properties

availabilities → List<SearchAvailability>
Structured open hours information.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → SearchState?
Current company working status
no setter
text → String
Human-readable localized open hours description.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchWorkingHours other) → bool
The equality operator.
override