OneOrg constant
SuggestType
const OneOrg
Organization that can be uniquely identified by search request.
Implementation
static const OneOrg = SuggestType(1 << 4);
Organization that can be uniquely identified by search request.
static const OneOrg = SuggestType(1 << 4);