BicycleFlags class final

Indicates whether the suggested route has one or more of the specified properties.

Available extensions

Constructors

BicycleFlags({required bool requiresAccessPass, required bool hasAutoRoad})
const

Properties

hasAutoRoad → bool
Indicates whether the suggested route includes automotive roads.
final
hashCode → int
The hash code for this object.
no setteroverride
requiresAccessPass → bool
Indicates whether the suggested route requires an access pass.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant BicycleFlags other) → bool
The equality operator.
override