BicycleLeg class abstract final

Leg of the route.

Implemented types

Constructors

BicycleLeg(BicycleWeight weight, Subpolyline geometry)
factory

Properties

geometry → Subpolyline
Path of the route polyline for the route leg.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → BicycleWeight
Quantitative characteristics of the route leg.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant BicycleLeg other) → bool
The equality operator.
override