BicycleRoute class abstract

Bicycle route.

Implemented types

Constructors

BicycleRoute()

Properties

constructions → List<BicycleConstructionSegment>
List of specific constructions along the bicycle path, such as stairs or crossings. See transport_bicycle_construction.BicycleConstructionID for a complete list of constructions. BicycleConstructionSegment.subpolyline fields of all segments cover the entire BicycleRoute.geometry.
no setter
flags → BicycleFlags?
Specific properties of the route.
no setter
geometry → Polyline
Polyline with geometry of the route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
legs → List<BicycleLeg>
Legs of the route.
no setter
restrictedEntries → List<BicycleRestrictedEntry>
List of restricted entries with their positions along the path.
no setter
routeId → String?
Unique route id.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections → List<BicycleSection>
Sections of the route.
no setter
trafficTypes → List<BicycleTrafficTypeSegment>
List of traffic types (transport_bicycle_traffic_type.BicycleTrafficTypeID) along the path. Traffic type for an edge means who the road is designed for, such as pedestrians or cyclists. See transport_bicycle_traffic_type.BicycleTrafficTypeID for a complete list of types. Fields BicycleTrafficTypeSegment.subpolyline of all segments cover whole BicycleRoute.geometry
no setter
uriMetadata → UriObjectMetadata
Route URI, which can be used with transport_bicycle_bicycle_router.BicycleRouter to fetch additional information about the route or can be bookmarked for future reference.
no setter
viaPoints → List<BicycleViaPoint>
List of via points on the path. See transport_bicycle_intermediate_points.BicycleViaPoint for details
no setter
wayPoints → List<BicycleWayPoint>
List of waypoints on the route. See transport_bicycle_intermediate_points.BicycleWayPoint for details.
no setter
weight → BicycleWeight
Quantitative characteristics of the route.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited