BicycleRouter class abstract

Provides methods for submitting bicycle routing requests.

Implemented types
Annotations
  • @Deprecated('use masstransit.BicycleRouterV2 instead')

Constructors

BicycleRouter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestRoutes(BicycleVehicleType type, BicycleSessionRouteListener routeListener, {required List<RequestPoint> points}) → BicycleSession
Submits a request to find a bicycle route.
requestRoutesSummary(BicycleVehicleType type, BicycleSummarySessionSummaryListener summaryListener, {required List<RequestPoint> points}) → BicycleSummarySession
Submits a request to fetch a brief summary of the bicycle routes.
resolveUri(BicycleSessionRouteListener routeListener, {required String uri}) → BicycleSession
Submits a request to retrieve detailed information on a bicycle route by URI.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited