BicycleSection class abstract final

Section of the route.

Implemented types

Constructors

BicycleSection(BicycleWeight weight, Subpolyline geometry)
factory

Properties

geometry → Subpolyline
Path of the route polyline for this section.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → BicycleWeight
Quantitative characteristics of a route or route section.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant BicycleSection other) → bool
The equality operator.
override