FitnessOptions class final

Available extensions

Constructors

FitnessOptions({bool avoidSteep = false, bool avoidStairs = false})
const

Properties

avoidStairs → bool
If true, router will try avoid stairs.
final
avoidSteep → bool
If true, router will try avoid steep (in height meaning) routes.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant FitnessOptions other) → bool
The equality operator.
override