MasstransitAnnotation class abstract final

Contains info about actions on part of route. Either action or landmark should be non-empty.

Implemented types

Constructors

MasstransitAnnotation(PolylinePosition position, MasstransitActionID? action, MasstransitLandmarkID? landmark, MasstransitToponym? toponym)
factory

Properties

action → MasstransitActionID?
Action
no setter
hashCode → int
The hash code for this object.
no setteroverride
landmark → MasstransitLandmarkID?
Landmark
no setter
position → PolylinePosition
Position of annotation on part of route
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toponym → MasstransitToponym?
The toponym of the location.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitAnnotation other) → bool
The equality operator.
override