MasstransitBoardingOptions class abstract final

Contains information about underground or railway boarding recommendations.

Implemented types
Implementers

Properties

area → List<MasstransitBoardingOptionsBoardingArea>
Vector of recommended areas to board.
no setter
hashCode → int
The hash code for this object.
no setteroverride
railwayOptions → MasstransitRailwayOptions
Options about boarding to trains.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitBoardingOptions other) → bool
The equality operator.
override