MasstransitConnector class final

Connectors connect two floors, indoor and outdoor, two indoor plans. Connectors do not have single level id and name but still are considered a part of the indoor plan. Examples: stairs, elevators, escalators, travolators, transitions, route segment that goes from outdoor to indoor (through the entrance) and vica versa.

Available extensions

Properties

from → MasstransitIndoorLevel?
A level (floor) where the connector begins. Null means outdoor.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → MasstransitIndoorLevel?
A level (floor) where the connector ends. Null means outdoor.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitConnector other) → bool
The equality operator.
override