MasstransitConstructionMask class final

Constructions that can be found on pedestrian, bicycle paths or on mass transit transfers.

Available extensions

Constructors

MasstransitConstructionMask({MasstransitStairs? stairs, MasstransitPass? pass, required bool crosswalk, required bool binding, required bool transition, required bool tunnel, MasstransitTravolator? travolator, required bool indoor, required bool spiral, MasstransitEscalator? escalator, MasstransitElevator? elevator})
const

Properties

binding → bool
Edge connecting the route endpoint to the route network.
final
crosswalk → bool
Crossing that is not an underground tunnel or a bridge.
final
elevator → MasstransitElevator?
final
escalator → MasstransitEscalator?
final
hashCode → int
The hash code for this object.
no setteroverride
indoor → bool
Air-conditioned place. Can be a covered gallery, a mall or any other climate-static edges.
final
pass → MasstransitPass?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spiral → bool
Spiral object, e.g. stairs
final
stairs → MasstransitStairs?
final
transition → bool
Transfer. For example, transfer from one underground line to another or transfer from an underground station to an exit from it.
final
travolator → MasstransitTravolator?
final
tunnel → bool
Tunnel that is not a crossing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitConstructionMask other) → bool
The equality operator.
override