MasstransitConstructionSegment class final

Describes part of pedestrian or bicycle path with the same construction.

Available extensions

Constructors

MasstransitConstructionSegment(Subpolyline subpolyline, MasstransitConstructionMask constructionMask)
const

Properties

constructionMask → MasstransitConstructionMask
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subpolyline → Subpolyline
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitConstructionSegment other) → bool
The equality operator.
override