MasstransitDropOffOptions class abstract final

Options about railway station dropoff expectations.

Implemented types
Implementers

Constructors

MasstransitDropOffOptions(MasstransitRailwayOptions railwayOptions)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
railwayOptions MasstransitRailwayOptions
Options about dropoff from trains.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitDropOffOptions other) bool
The equality operator.
override