MasstransitElevationData class abstract final

Information of elevation gain in loss in a fitness section

Implemented types

Constructors

MasstransitElevationData(LocalizedValue totalAscent, LocalizedValue totalDescent, LocalizedValue? steps, LocalizedValue kilocalories, List<MasstransitInclineSection> inclineSections, List<MasstransitElevationPoint> elevationSegments)
factory

Properties

elevationSegments → List<MasstransitElevationPoint>
List of elevation for each point of the section polyline
no setter
hashCode → int
The hash code for this object.
no setteroverride
inclineSections → List<MasstransitInclineSection>
List of sections with notable incline
no setter
kilocalories → LocalizedValue
The number of kilocalories consumed by an average person to cover the distance
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps → LocalizedValue?
The number of steps required to cover the distance for an average person
no setter
totalAscent → LocalizedValue
Total ascent in meters
no setter
totalDescent → LocalizedValue
Total descent in meters
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitElevationData other) → bool
The equality operator.
override