MasstransitElevationPoint class final

Information of elevation in point

Available extensions

Constructors

MasstransitElevationPoint({required double elevation})
const

Properties

elevation → double
Elevation levels in meters
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitElevationPoint other) → bool
The equality operator.
override