MasstransitEssentialStop class abstract final

Essential stop on thread

Implemented types

Properties

hashCode → int
The hash code for this object.
no setteroverride
info → MasstransitEssentialStopInfo
Info for stop MasstransitEssentialStopInfo.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop → MasstransitStop
Stop on the thread
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitEssentialStop other) → bool
The equality operator.
override