MasstransitEssentialStopInfo class final

Info for essential stop

Available extensions

Constructors

MasstransitEssentialStopInfo({bool first_stop = false, bool intermediate_terminus = false, bool important = false, bool last_stop = false})
const

Properties

first_stop → bool
First stop on thread
final
hashCode → int
The hash code for this object.
no setteroverride
important → bool
Important stop on thread
final
intermediate_terminus → bool
Intermediate terminus stop on thread
final
last_stop → bool
Last stop on thread
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitEssentialStopInfo other) → bool
The equality operator.
override