MasstransitIndoorSegment class final

Indoor segment of the fitness section.

Available extensions

Constructors

MasstransitIndoorSegment(MasstransitIndoorSegmentIndoorData indoorData, Subpolyline subpolyline)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
indoorData → MasstransitIndoorSegmentIndoorData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subpolyline → Subpolyline
A span of this level on the route geometry.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitIndoorSegment other) → bool
The equality operator.
override