MasstransitLine class abstract final

Describes a public transport line.

Inheritance
Implemented types

Constructors

MasstransitLine(String id, String name, List<String> vehicleTypes, MasstransitLineStyle? style, bool isNight, String? uri, String? shortName, String? transportSystemId)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
Line ID.
no setter
isNight → bool
True if the line operates only at night.
no setter
name → String
Line name.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String?
Subway short line name.
no setter
style → MasstransitLineStyle?
Line style; see MasstransitLineStyle.
no setter
transportSystemId → String?
Subway transport system ID.
no setter
uri → String?
URI for a line.
no setter
vehicleTypes → List<String>
List of line types. Starts from the most detailed, ends with the most general.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitLine other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<MasstransitLine>
final