MasstransitPayment class final

Available extensions

Constructors

MasstransitPayment(TaxiMoney price, {MasstransitPaymentMedia? paymentMedia})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
paymentMedia → MasstransitPaymentMedia?
Contains information about the payment media.
final
price → TaxiMoney
Cost of travel in the vehicle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitPayment other) → bool
The equality operator.
override