MasstransitRailwayOptions class abstract final

Contains information about boarding to or dropOff from trains.

Implemented types

Constructors

MasstransitRailwayOptions(String? tracks, String? platforms, bool uncertain)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
platforms → String?
Departure platform annotation, e.g. "2 platform".
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracks → String?
Departure track annotation, e.g. "3 or 4 track".
no setter
uncertain → bool
Flag of track/platform selection uncertainty to suggest user double-check it in the station.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitRailwayOptions other) → bool
The equality operator.
override