MasstransitRoute class abstract

Contains information about a route constructed by the mass transit router.

Implemented types

Constructors

MasstransitRoute()

Properties

geometry → Polyline
Polyline of the entire route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
metadata → MasstransitRouteMetadata
General route information.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections → List<MasstransitSection>
Vector of sections of the route.
no setter
uriMetadata → UriObjectMetadata
Route URI, which can be used with transport_masstransit_masstransit_router.MasstransitRouter to fetch additional information about the route or can be bookmarked for future reference.
no setter
wayPoints → List<MasstransitWayPoint>
List of route waypoints. See transport_masstransit_way_point.MasstransitWayPoint for details
no setter

Methods

distanceBetweenPolylinePositions(PolylinePosition from, PolylinePosition to) → double
Return distance between two polyline positions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
timeBetweenPolylinePositions(PolylinePosition from, PolylinePosition to) → double
Return travel time between two polyline positions.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited