MasstransitRouteMetadata class abstract final

Contains information associated with a route constructed by the mass transit router.

Inheritance
Implemented types

Constructors

MasstransitRouteMetadata(MasstransitWeight weight, MasstransitRouteSettings? settings, MasstransitTravelEstimation? estimation, List<MasstransitWayPoint> wayPoints, String? routeId, MasstransitFlags? flags, List<MasstransitComfortTag> comfortTags, MasstransitStairsSummary stairsSummary, List<MasstransitRoutePaymentOption> paymentOptions, String? routeExplanation)
factory

Properties

comfortTags → List<MasstransitComfortTag>
no setter
estimation → MasstransitTravelEstimation?
Arrival and departure time estimations for time-dependent routes.
no setter
flags → MasstransitFlags?
Flags which contains route properties
no setter
hashCode → int
The hash code for this object.
no setteroverride
paymentOptions → List<MasstransitRoutePaymentOption>
List of payment options with prices for the whole route.
no setter
routeExplanation → String?
no setter
routeId → String?
Unique route id.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → MasstransitRouteSettings?
Route settings that were used by the mass transit router.
no setter
stairsSummary → MasstransitStairsSummary
no setter
wayPoints → List<MasstransitWayPoint>
List of route waypoints. See transport_masstransit_way_point.MasstransitWayPoint for details
no setter
weight → MasstransitWeight
Contains the route time, distance of the walking part, and the number of transfers.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitRouteMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<MasstransitRouteMetadata>
final