MasstransitRouteSerializer class abstract

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load(ByteBuffer data) → MasstransitRoute?
Deserializes the route. Return Deserialized Route. Null in case of any errors.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(MasstransitRoute route) → ByteBuffer
Serializes the route. Return Route's serialized representation. Empty array in case of any errors.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited