MasstransitRouteStop class abstract final

Implemented types

Constructors

MasstransitRouteStop(MasstransitRouteStopMetadata metadata, Point position)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
metadata → MasstransitRouteStopMetadata
General information about a stop on a route and optionally about its exit
no setter
position → Point
Coordinates of the stop.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitRouteStop other) → bool
The equality operator.
override