MasstransitRouteStopMetadata class abstract final

The metadata about the mass transit stop.

Inheritance
Implemented types

Constructors

MasstransitRouteStopMetadata(MasstransitStop stop, MasstransitStop? stopExit, Point? exitPoint, MasstransitStop? stopEntrance, Point? entrancePoint)
factory

Properties

entrancePoint → Point?
Coordinates of underground station entrance
no setter
exitPoint → Point?
Coordinates of underground station exit
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop → MasstransitStop
Route stop information.
no setter
stopEntrance → MasstransitStop?
Underground station entrance
no setter
stopExit → MasstransitStop?
Underground station exit
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitRouteStopMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<MasstransitRouteStopMetadata>
final