MasstransitRouter class abstract

Provides methods for submitting mass transit routing requests.

Implemented types

Constructors

MasstransitRouter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestRoutes(TransitOptions transitOptions, RouteOptions routeOptions, RouteHandler routeListener, {required List<RequestPoint> points}) → MasstransitSession
Submits a request to find mass transit routes.
requestRoutesSummary(TransitOptions transitOptions, RouteOptions routeOptions, SummaryHandler summaryListener, {required List<RequestPoint> points}) → MasstransitSummarySession
Submits a request to fetch a brief summary of a mass transit route.
resolveUri(TimeOptions timeOptions, RouteHandler routeListener, {required String uri}) → MasstransitSession
Submits a request to retrieve detailed information on a mass transit route by URI.
routeSerializer() → MasstransitRouteSerializer
Returns a route serializer instance.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited