MasstransitSectionMetadata class abstract final

General information about a section of a route. The MasstransitSectionMetadata.data field describes the type of section: wait, walk, transfer, or transport, and related data. Related data can be set for walk and transfer sections. This data is a vector of construction types of corresponding geometry segments.

Implemented types

Properties

data → MasstransitSectionMetadataSectionData
Contains information that is specific to a section type: wait, walk, transfer, or ride transport.
no setter
estimation → MasstransitTravelEstimation?
Arrival and departure time estimations. This field is set only for time-dependent routes.
no setter
hashCode → int
The hash code for this object.
no setteroverride
legIndex → int
Part of the route polyline for the route leg. A leg is a part of the route between two consecutive waypoints.
no setter
paymentOptions → List<MasstransitSectionPaymentOption>
List of payment options with prices for the current section.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → MasstransitWeight
Contains the route traveling time, distance of the walking part, and the number of transfers.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitSectionMetadata other) → bool
The equality operator.
override