MasstransitSectionMetadataSectionData class final

A choice of information specific to the section type.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asFitness() → MasstransitFitness?
asTaxi() → MasstransitTaxi?
asTransfer() → MasstransitTransfer?
asVectorMasstransitTransport() → List<MasstransitTransport>?
asWait() → MasstransitWait?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onWait(MasstransitWait value), required void onFitness(MasstransitFitness value), required void onTransfer(MasstransitTransfer value), required void onTaxi(MasstransitTaxi value), required void onVectorMasstransitTransport(List<MasstransitTransport> value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited