MasstransitSectionPaymentOption class final

Available extensions

Properties

appliedFare → MasstransitSectionPaymentOptionAppliedFare
final
hashCode → int
The hash code for this object.
no setteroverride
payment → MasstransitPayment?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitSectionPaymentOption other) → bool
The equality operator.
override