MasstransitStairs class final

Represents stairs objects along the route

Available extensions

Constructors

MasstransitStairs(MasstransitStairsDirection direction, {required bool hasRamp})
const

Properties

direction → MasstransitStairsDirection
final
hashCode → int
The hash code for this object.
no setteroverride
hasRamp → bool
Does stairs have a ramp
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitStairs other) → bool
The equality operator.
override