MasstransitStop class abstract final

Describes a public transport stop.

Inheritance
Implemented types

Constructors

MasstransitStop(String id, String name, String? additionalName, MasstransitStopFeatureMask? features, List<MasstransitTransportContour> transportContours)
factory

Properties

additionalName → String?
Additional stop name. Can be a local number or specifying index. Similar to thread description, but for stops
no setter
features → MasstransitStopFeatureMask?
Additional stop features.
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → String
Stop ID.
no setter
name → String
Stop name.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transportContours → List<MasstransitTransportContour>
Describes transport contours represented at this Stop.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitStop other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<MasstransitStop>
final