MasstransitSummary class abstract final

Contains brief information associated with a route constructed by the mass transit router.

Implemented types

Constructors

MasstransitSummary(MasstransitWeight weight, MasstransitTravelEstimation? estimation, MasstransitFlags? flags)
factory

Properties

estimation → MasstransitTravelEstimation?
Arrival and departure time estimations for time-dependent routes.
no setter
flags → MasstransitFlags?
Specific properties of the route.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → MasstransitWeight
Contains the route time, distance of the walking part, and the number of transfers.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitSummary other) → bool
The equality operator.
override