MasstransitThreadStop class abstract final

Implemented types

Constructors

MasstransitThreadStop(MasstransitStop stop, Point position)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → Point
Coordinates of the thread stop.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop → MasstransitStop
Stop on a thread.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitThreadStop other) → bool
The equality operator.
override