MasstransitToponym class final

Available extensions

Constructors

MasstransitToponym({String? toponym, String? accusativeToponym})
const

Properties

accusativeToponym → String?
Toponym in accusative case with preposition
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toponym → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitToponym other) → bool
The equality operator.
override