MasstransitTrafficTypeSegment class final

Describes part of bicycle or scooter path with the same traffic type.

Available extensions

Constructors

MasstransitTrafficTypeSegment(MasstransitTrafficTypeID trafficType, Subpolyline subpolyline)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subpolyline → Subpolyline
final
trafficType → MasstransitTrafficTypeID
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTrafficTypeSegment other) → bool
The equality operator.
override