MasstransitTransportContour class abstract final

Describes transport contours and it's properties

Implemented types

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
Contour name
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → MasstransitTransportContourStyle?
Contour style; see MasstransitTransportContourStyle.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTransportContour other) → bool
The equality operator.
override