MasstransitTransportStop class abstract final

The data about the public transport stop.

Implemented types
Implementers

Constructors

MasstransitTransportStop(MasstransitStop stop, Point position)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
position → Point
Coordinates of the stop.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stop → MasstransitStop
Information about public transport stops.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTransportStop other) → bool
The equality operator.
override