MasstransitTransportThreadAlert class final

TransportThreadAlert are important annotations for mass transit ride sections of routes.

Available extensions

Properties

closed → MasstransitTransportThreadAlertClosed?
The value is set if the thread is not operational on that day. Only one of the values close, closedUntil and lastTrip is set for an alert.
final
closedUntil → MasstransitTransportThreadAlertClosedUntil?
The value is set if the thread is not operational until the specified time. Only one of the values close, closedUntil and lastTrip is set for an alert.
final
hashCode → int
The hash code for this object.
no setteroverride
lastTrip → MasstransitTransportThreadAlertLastTrip?
The value is set if this trip is the last trip for the thread. Only one of the values close, closedUntil and lastTrip is set for an alert.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Standard alert text. Simple clients could use this text to get a pre-formatted message. If the client is unable to recognize the known structured alert, it should use the text field instead.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTransportThreadAlert other) → bool
The equality operator.
override