MasstransitTransportThreadAlertClosed class final

Thread is not operational on that day.

Available extensions

Constructors

MasstransitTransportThreadAlertClosed({required bool dummy})
const

Properties

dummy → bool
Dummy field which is used here because IDL does not support structs without fields.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTransportThreadAlertClosed other) → bool
The equality operator.
override