MasstransitTransportThreadAlertLastTrip class final

Last trip for the thread. Allows to get the time it takes to get to the end of the route.

Available extensions

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → Time
Time required to finish the trip.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTransportThreadAlertLastTrip other) → bool
The equality operator.
override