MasstransitWeight class final

Numeric characteristics of a route or a route section.

Available extensions

Constructors

MasstransitWeight(LocalizedValue time, LocalizedValue walkingDistance, {required int transfersCount})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → LocalizedValue
Travel time for a route or a route section.
final
transfersCount → int
The number of transfers for a route or a route section.
final
walkingDistance → LocalizedValue
Distance of the pedestrian part of the route or a route section.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitWeight other) → bool
The equality operator.
override