TimeOptions class final

Desired departure/arrival time settings. Only one the departureTime and arrivalTime fields should be specified.

Constructors

TimeOptions({DateTime? departureTime, DateTime? arrivalTime})
const

Properties

arrivalTime → DateTime?
Desired arrival time in UTC for a time-dependent route request. The value is specified in milliseconds. This option cannot be used with departureTime.
final
departureTime → DateTime?
Desired departure time in UTC for a time-dependent route request. The value is specified in milliseconds. This option cannot be used with arrivalTime.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant TimeOptions other) → bool
The equality operator.
override