TransitOptions class final

User-defined options, like time options and filter options.

Available extensions

Constructors

TransitOptions(TimeOptions timeOptions, {FilterVehicleTypes avoid = FilterVehicleTypes.None})
const

Properties

avoid → FilterVehicleTypes
Transport types that the router will avoid. The value should be one of FilterVehicleTypes, or their bitwise 'OR' combination.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeOptions → TimeOptions
Desired departure/arrival time settings. Empty transport_masstransit_options.TimeOptions for requests that are not time-dependent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant TransitOptions other) → bool
The equality operator.
override