Transport class abstract

Implemented types
Implementers

Constructors

Transport()

Properties

adjustedClock → AdjustedClock
Returns the clock that is constantly synchronized with the server.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBicycleRouter() → BicycleRouter
Creates a manager that builds bicycle routes using the origin and destination points.
createBicycleRouterV2() → BicycleRouterV2
Creates a manager that builds bicycle routes using the origin and destination points.
createElectricBikeRouter() → BicycleRouterV2
Creates a manager that builds electric bike routes using the origin and destination points.
createMasstransitRouter() → MasstransitRouter
Creates a manager that builds public transit routes using the origin and destination points.
createPedestrianRouter() → PedestrianRouter
Creates a manager that builds pedestrian routes using the origin and destination points.
createScooterRouter() → BicycleRouterV2
Creates a manager that builds scooter routes using the origin and destination points.
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited