TransportStopMetadataTransportStopInfo class abstract final

Implemented types

Constructors

TransportStopMetadataTransportStopInfo(List<String> threadIds, List<RawTransportStop> stops)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stops → List<RawTransportStop>
no setter
threadIds → List<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant TransportStopMetadataTransportStopInfo other) → bool
The equality operator.
override