VehicleRawData class abstract final

Represents a mass transport unit on the map

Inheritance
Implemented types

Constructors

VehicleRawData(String id, String threadId, MasstransitLine line)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
Id of a vehicle
no setter
line → MasstransitLine
Stores the vehicle's public transport line info
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadId → String
Id of the line thread on which the vehicle is running
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant VehicleRawData other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<VehicleRawData>
final