MasstransitIndoorLevel class final
Indoor level (floor).
- Available extensions
Constructors
- MasstransitIndoorLevel({required String levelId, required String levelName, required int planId})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- levelId → String
-
Level id that can be passed to the Router.
final
- levelName → String
-
Localized level name.
final
- planId → int
-
Id of the indoor plan the level belongs to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant MasstransitIndoorLevel other) → bool -
The equality operator.
override